# LRU-pytorch
An implementation of Linear Recurrent Units, by Deepmind, in Pytorch. LRUs are inspired by Deep State-Space Machines, particularly S4 and S5.

# Notes:
Since Pytorch does not have associative scans as of now, the Pytorch implementation will very likely be slower than a JAX implementation.

# Paper:
<a href='https://arxiv.org/abs/2303.06349'>Resurrecting Recurrent Neural Networks for Long Sequences</a>



